@@ -255,7 +255,7 @@ class PhContextFacade(object):
         secret_key = os.getenv("AWS_SECRET_ACCESS_KEY")
         cmd_arr = ["spark-submit",
                    "--master", "yarn",
-                   "--deploy-mode", "client",
+                   "--deploy-mode", "cluster",
                    "--conf", "spark.driver.memory=1g",
                    "--conf", "spark.driver.cores=1",
                    "--conf", "spark.executor.memory=2g",
